import React, { Component } from "react";

export default class FilterDialog extends Component {
    constructor() {
        super();

        this.state = {
            filters: [],
            appliedFilters: [],
        };
    }

    addFilter(newFilter) {
        let filters = [];
        if (this.state.appliedFilters.includes(newFilter)) {
            filters = this.state.appliedFilters.filter(
                (filter) => filter !== newFilter
            );
        } else {
            filters = [...this.state.appliedFilters, newFilter];
        }
        this.setState({
            ...this.state,
            appliedFilters: filters,
        });
    }

    clearFilters() {
        this.setState({
            ...this.state,
            appliedFilters: [],
        });
    }

    componentDidMount() {
        this.setState({
            filters: this.props.filters,
            appliedFilters: this.props.appliedFilters,
        });
    }

    componentDidUpdate() {
        if (this.props.appliedFilters !== this.state.appliedFilters) {
            this.props.setFilters(this.state.appliedFilters);
        }
    }

    render() {
        return (
            <div className='FilterDialog'>
                <div className='FilterDialog__Content'>
                    <div className='FilterDialog__Title'>
                        {this.props.filterTitle ?? "Filtrar"}
                    </div>
                    <div className='FilterDialog__Filters'>
                        {this.state.filters.map((filter) => {
                            let inputTag = filter
                                .replaceAll("-", "_")
                                .replaceAll(" ", "_")
                                .replaceAll("/", "_");
                            return (
                                <div key={"key_" + filter}>
                                    <input
                                        type='checkbox'
                                        name={"filter_" + inputTag}
                                        id={"filter_" + inputTag}
                                        onChange={() => this.addFilter(filter)}
                                        checked={this.state.appliedFilters.includes(
                                            filter
                                        )}
                                    />
                                    <label htmlFor={"filter_" + inputTag}>
                                        {filter}
                                    </label>
                                </div>
                            );
                        })}
                    </div>
                    <div className='FilterDialog__Footer'>
                        <div
                            className='Button Button__secondary'
                            onClick={() => this.clearFilters()}>
                            Limpiar
                        </div>
                        <div
                            className='Button Button__primary'
                            onClick={() => this.props.closeDialog()}>
                            Cerrar
                        </div>
                    </div>
                </div>
            </div>
        );
    }
}
