import React, { Component } from "react";

import AppContext from "@context/AppContext";
import axios from "axios";
import endpoints from "@services/Api/endpoints";
import Commons from "@utils/Commons";
import TelegramHelper from "@utils/TelegramHelper";

export default class FrmAssignUser extends Component {
    constructor() {
        super();

        this.state = {
            sellers: [],
            disabledBtn: true,
            userName: "",
        };
    }

    static contextType = AppContext;

    getMsgTelegram(assignedUser) {
        switch (this.props.entityType) {
            case "bid":
                return this.props.userType === "seller"
                    ? Commons.msgTemplates.bid.msgSeller
                          .replace("%BID%", this.props.registry.nombre)
                          .replace("%SELLER%", this.props.registry.usuario)
                          .replace("%USER%", assignedUser)
                    : Commons.msgTemplates.bid.msgFollower
                          .replace("%BID%", this.props.registry.nombre)
                          .replace("%SELLER%", this.props.registry.usuario)
                          .replace("%USER%", assignedUser);
            case "presale":
                return this.props.userType === "seller"
                    ? Commons.msgTemplates.presale.msgSeller
                          .replace(
                              "%ENTERPRISE%",
                              this.props.registry.nombre_empresa
                          )
                          .replace(
                              "%CUSTOMER%",
                              this.props.registry.nombre_cliente
                          )
                          .replace("%SELLER%", this.props.registry.usuario)
                          .replace("%USER%", assignedUser)
                    : Commons.msgTemplates.presale.msgFollower
                          .replace(
                              "%ENTERPRISE%",
                              this.props.registry.nombre_empresa
                          )
                          .replace(
                              "%CUSTOMER%",
                              this.props.registry.nombre_cliente
                          )
                          .replace("%SELLER%", this.props.registry.usuario)
                          .replace("%USER%", assignedUser);
            case "education":
                return this.props.userType === "seller"
                    ? Commons.msgTemplates.education.msgSeller
                          .replace(
                              "%INSTITUTION%",
                              this.props.registry.nombre_institucion
                          )
                          .replace(
                              "%CUSTOMER%",
                              this.props.registry.nombre_cliente
                          )
                          .replace("%SELLER%", this.props.registry.usuario)
                          .replace("%USER%", assignedUser)
                    : Commons.msgTemplates.education.msgFollower
                          .replace(
                              "%INSTITUTION%",
                              this.props.registry.nombre_institucion
                          )
                          .replace(
                              "%CUSTOMER%",
                              this.props.registry.nombre_cliente
                          )
                          .replace("%SELLER%", this.props.registry.usuario)
                          .replace("%USER%", assignedUser);
            default:
                break;
        }
    }

    async assignUser() {
        try {
            const select = document.getElementById("seller");
            const data = {
                userId: select.value,
                estatus:
                    this.props.entityType == "bid"
                        ? Commons.statuses.final_initial
                        : Commons.statuses.final2_initial,
            };

            let url = this.props.url;
            url = url.replace("%ID%", this.props.registry.id);

            await axios.post(url, data).then(async (response) => {
                this.context.setMessage({
                    type: "success",
                    message: response.data.message,
                });

                await axios
                    .get(this.props.urlData)
                    .then((response) => {
                        TelegramHelper.sendMessage(
                            this.getMsgTelegram(this.state.userName),
                            this.props.telegramChannel
                        );
                        this.props.updateData(response);
                    })
                    .catch((error) => {
                        console.error(error);

                        this.context.setMessage({
                            type: "error",
                            message: "Ocurrió un error, intente más tarde",
                        });
                    });

                this.props.closeModal();
            });
        } catch (error) {
            console.error(error);
            this.context.setMessage({
                type: "error",
                message: error.response.data.error,
            });
        }
    }

    onChangeSelection(evt) {
        this.setState({
            userName: evt.target.options[evt.target.selectedIndex].label,
        });
    }

    componentDidMount() {
        axios
            .get(endpoints.users.getSellers + "?userRole=preventa")
            .then((response) => {
                this.setState({
                    sellers: response.data.users,
                    disabledBtn: !(response.data.users.length > 0),
                    userName: response.data.users[0].name,
                });
            })
            .catch((error) => {
                console.error(error);
                this.context.setMessage({
                    type: "error",
                    message: "Error al obtener los usuarios",
                });
            });
    }

    render() {
        return (
            <div className='Dialog'>
                <div className='Dialog__Content Dialog-maxContent'>
                    <div className='Dialog__Title'>
                        Asignar {this.props.type ?? "vendedor"}
                    </div>
                    <div className='Dialog__Body'>
                        <div className='Form__Group'>
                            <div className='Form__Input'>
                                <select
                                    name='seller'
                                    id='seller'
                                    onChange={(evt) =>
                                        this.onChangeSelection(evt)
                                    }>
                                    {this.state.sellers.map((seller) => (
                                        <option
                                            value={seller.id}
                                            key={seller.id}>
                                            {seller.name}
                                        </option>
                                    ))}
                                </select>
                                <label htmlFor='seller'>
                                    {this.props.label}
                                </label>
                            </div>
                        </div>
                    </div>
                    <div className='Dialog__Footer'>
                        <div
                            className='Button Button__secondary'
                            onClick={() => this.props.closeModal()}>
                            Cerrar
                        </div>
                        <div
                            className={`Button ${
                                this.state.disabledBtn
                                    ? "Button__disabled"
                                    : "Button__primary"
                            }`}
                            onClick={
                                this.state.disabledBtn
                                    ? null
                                    : () => this.assignUser()
                            }>
                            Guardar
                        </div>
                    </div>
                </div>
            </div>
        );
    }
}
