import React, { Component } from "react";
import axios from "axios";
import Image from "next/image";

import logoAti from "@img/logo_ati.jpg";

import AppContext from "@context/AppContext";
import endpoints from "@services/Api/endpoints";
import DateFormatter from "../utils/DateFormatter";
import TelegramHelper from "../utils/TelegramHelper";
import ConvertArray from "../utils/ConvertArray";
import Commons from "@utils/Commons";
import DialogConfirm from "./DialogConfirm";

export default class FrmBid extends Component {
    constructor() {
        super();

        this.state = {
            title: "Registro de licitación",
            titleReview: "Revisión del formulario",
            valid: true,
            optLugaresOtrosSelected: false,
            optPartidasOtrosSelected: false,
            regexpUrl:
                /https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{1,256}\.[a-zA-Z0-9()]{1,6}\b([-a-zA-Z0-9()@:%_\+.~#?&//=]*)/,
            regexpEmail: /^[\w-\.]+@([\w-]+\.)+[\w-]{2,4}$/g,
            lugaresPublicacion: [
                "COMPRANET",
                "ADMINISTRACION",
                "LICYGOB",
                "LA DEPENDENCIA",
                "TITA",
                "Otros",
            ],
            partidas: [
                "EQUIPO DE COMPUTO",
                "ENERGIA",
                "PROYECCION",
                "SOFTWARE",
                "PAPELERIA",
                "Otros",
            ],
            urlSave: endpoints.bid.post,
            formData: {},
            showDialogConfirm: false,
            isEditing: true,
        };
    }

    static contextType = AppContext;

    onChangeOtrosSelected(e, fieldName) {
        if (e.target.value.toLowerCase() == "otros") {
            let selected = true;
            if (e.target.type == "checkbox") {
                selected = e.target.checked;
            }

            this.setState({
                ...this.state,
                [fieldName]: selected,
            });
        } else {
            this.setState({
                ...this.state,
                [fieldName]: false,
            });
        }
    }

    validateForm() {
        let textInputs = document.querySelectorAll(
            `.Form__Bid input[type=text]`
        );
        let dateInputs = document.querySelectorAll(
            `.Form__Bid input[type=date]`
        );
        let timeInputs = document.querySelectorAll(
            `.Form__Bid input[type=time]`
        );
        let linkInputs = document.querySelectorAll(
            `.Form__Bid input[type=url]`
        );

        let formaEntrega = document.getElementsByName("comoSeEntregan");
        let juntaObligatoria = document.getElementsByName("juntaObligatoria");
        let tipoJunta = document.getElementsByName("presencialOdigital");
        let requirePreventa = document.getElementsByName("requierePreventa");

        let inputsToValidate = [
            ...textInputs,
            ...dateInputs,
            ...timeInputs,
            ...linkInputs,
        ];

        Commons.validateInputs(inputsToValidate);
        Commons.validateInputRadio(formaEntrega);
        Commons.validateInputRadio(juntaObligatoria);
        Commons.validateInputRadio(tipoJunta);
        Commons.validateInputRadio(requirePreventa);
    }

    getFormData() {
        let formData = [];
        formData["usuario"] = this.context.state.user.name;

        let textInputs = document.querySelectorAll(
            `.Form__Bid input[type=text]`
        );
        let dateInputs = document.querySelectorAll(
            `.Form__Bid input[type=date]`
        );
        let timeInputs = document.querySelectorAll(
            `.Form__Bid input[type=time]`
        );
        let linkInputs = document.querySelectorAll(
            `.Form__Bid input[type=url]`
        );
        let selectInputs = document.querySelectorAll(`.Form__Bid select`);

        let formaEntrega = document.getElementsByName("comoSeEntregan");
        let juntaObligatoria = document.getElementsByName("juntaObligatoria");
        let tipoJunta = document.getElementsByName("presencialOdigital");
        let requirePreventa = document.getElementsByName("requierePreventa");

        let partidas = document.getElementsByName("partidas");

        let inputs = [
            ...textInputs,
            ...dateInputs,
            ...timeInputs,
            ...linkInputs,
            ...selectInputs,
        ];

        for (const input of inputs) {
            if (
                input.name == "dondePublicado" &&
                this.state.optLugaresOtrosSelected
            ) {
                formData[input.name] = document.getElementById(
                    "otrosLugarPublicacion"
                ).value;
            } else {
                formData[input.name] = input.value;
            }
        }

        let partidasSeleccionadas = "";
        for (const partida of partidas) {
            if (partida.checked) {
                if (partida.value.toLowerCase() == "otros") {
                    const otraPartida = document.getElementById("otraPartida");
                    partidasSeleccionadas += `${partida.value}, ${otraPartida.value}, `;
                } else {
                    partidasSeleccionadas += `${partida.value}, `;
                }
            }
        }

        if (partidasSeleccionadas.length > 0) {
            partidasSeleccionadas = partidasSeleccionadas.substring(
                0,
                partidasSeleccionadas.length - 2
            );
        }

        formData["partidas"] = partidasSeleccionadas;

        const pushRadioValue = (radios, data) => {
            for (const radio of radios) {
                if (radio.checked) {
                    data[radio.name] = radio.value;
                }
            }

            return data;
        };

        formData = pushRadioValue(formaEntrega, formData);
        formData = pushRadioValue(juntaObligatoria, formData);
        formData = pushRadioValue(tipoJunta, formData);
        formData = pushRadioValue(requirePreventa, formData);

        return formData;
    }

    sendEmail(formData, correos) {
        const now = new Date();
        const time = DateFormatter.time(now);
        const date = DateFormatter.date(now, true);

        const horaLimiteEnvioPreguntas =
            formData["horaLimiteEnvioPreguntas"].split(":");
        const hora = parseInt(horaLimiteEnvioPreguntas[0]) - 1;
        const horaLimite = `${hora}:${horaLimiteEnvioPreguntas[1]}`;

        const data = {
            correosDestino: correos, // Array de direcciones de correo electrónico
            asunto: `Se ha registrado una nueva licitación ${formData["nombreLicitacion"]}`,
            mensaje: `
${time} ${date}
Se ha registrado una nueva licitación ${formData["nombreLicitacion"]}
<body>
    Nombre de la licitación: <strong>${formData["nombreLicitacion"]}</strong>
    Depedencia licitante: <strong>${formData["dependenciaLicitante"]}</strong>
    Dependecia de usuario: <strong>${formData["dependenciaUsuario"]}</strong>
    Empresas Participantes: <strong>${formData["empresaParticipantes"]}</strong>
    Fecha de publicación: <strong>${formData["fechaPublicacion"]}</strong>
    Donde se publico: <strong>${formData["dondePublicado"]}</strong>
    Fecha de envios de preguntas: <strong>${formData["fechaEnvioPreguntas"]}</strong>
    Hora limite de envios de preguntas: <strong>${horaLimite}</strong>
    Como se entregan: <strong>${formData["comoSeEntregan"]}</strong>
    Domicilio y/o Correo: <strong>${formData["domicilioCorreo"]}</strong>
    Fecha de junta de aclaraciones: <strong>${formData["fechaJuntaAclaraciones"]}</strong>
    Hora de registro de junta de aclaraciones: <strong>${formData["horaRegistroJA"]}</strong>
    Hora de junta de aclaraciones: <strong>${formData["horaJA"]}</strong>
    Domicili de junta de aclaraciones: <strong>${formData["domicilioJA"]}</strong>
    Es presencial o digital: <strong>${formData["presencialOdigital"]}</strong>
    Domicilio: <strong>${formData["domicilio"]}</strong>
    Fecha de presentación: <strong>${formData["fechaPresentacion"]}</strong>
    Hora de registro de presentación: <strong>${formData["horaRegistroPresentacion"]}</strong>
    Hora de apertura: <strong>${formData["horaApertura"]}</strong>
    Partidas: <strong>${formData["partidas"]}</strong>
    ¿Requiere preventa?: <strong>${formData["requierePreventa"]}</strong>
Link de la carpeta: <strong>${formData["linkCarpeta"]}</strong>
</body>`,
        };

        axios
            .post(endpoints.email_notification.send_mails, data)
            .catch((response) => {
                console.error("Error al enviar correos", response);
            });
    }

    sendTelegramMsg(formData) {
        const now = new Date();
        const time = DateFormatter.time(now);
        const date = DateFormatter.date(now, true);

        const horaLimiteEnvioPreguntas =
            formData["horaLimiteEnvioPreguntas"].split(":");
        const hora = parseInt(horaLimiteEnvioPreguntas[0]) - 1;
        const horaLimite = `${hora}:${horaLimiteEnvioPreguntas[1]}`;

        const message = `
    <b>${time} ${date}</b>
Se ha registrado una nueva licitación <b>${formData["nombreLicitacion"]}</b>
Empresas Participantes: <b>${formData["empresaParticipantes"]}</b>
Envío de preguntas: <b>${DateFormatter.date(
            formData["fechaEnvioPreguntas"]
        )} ${horaLimite}</b>
Junta de aclaraciones: <b>${DateFormatter.date(
            formData["fechaJuntaAclaraciones"]
        )} ${formData["horaJA"]}</b>
Presentación: <b>${DateFormatter.date(formData["fechaPresentacion"])} ${
            formData["horaApertura"]
        }</b>
Partidas: <b>${formData["partidas"]}</b>
¿Requiere preventa?: <b>${formData["requierePreventa"]}</b>
Link de la carpeta: <b>${formData["linkCarpeta"]}</b>`;

        try {
            TelegramHelper.sendMessage(message);
        } catch (error) {
            console.error("Send Telegram Message", error);
        }
    }

    storeBid() {
        try {
            const formData = this.getFormData();

            const data = ConvertArray.toObject(formData);

            axios
                .post(this.state.urlSave, data)
                .then((response) => {
                    this.context.setMessage({
                        type: "success",
                        message: "Licitación registrada correctamente",
                    });

                    if (!this.props.registry) {
                        this.sendEmail(formData, []);
                        this.sendTelegramMsg(formData);
                    }

                    axios.get(this.props.url).then((response) => {
                        this.props.updateData(response);
                    });
                    this.props.closeModal();
                })
                .catch((response) => {
                    console.error("storeBid", response);
                    this.context.setMessage({
                        type: "error",
                        message: "Ocurrió un error al registrar la licitación",
                    });
                });
        } catch (error) {
            this.context.setMessage({
                type: "error",
                message: `Ocurrió un error al guardar la licitación: ${error.name} ${error.message}`,
            });
        }
    }

    fillForm() {
        const registry = this.props.registry;

        if (registry) {
            document.getElementById("nombreLicitacion").value = registry.nombre;
            document.getElementById("dependenciaLicitante").value =
                registry.dependencia_licitante;
            document.getElementById("dependenciaUsuario").value =
                registry.dependencia_usuario;
            document.getElementById("empresaParticipantes").value =
                registry.empresa_participantes;
            document.getElementById("fechaPublicacion").value =
                DateFormatter.dateNormal(registry.fecha_publicacion, true);
            document.getElementById("fechaEnvioPreguntas").value =
                DateFormatter.dateNormal(registry.fecha_envio_preguntas, true);
            document.getElementById("horaLimiteEnvioPreguntas").value =
                registry.hora_limite_envio_preguntas;
            document.getElementById("formaEntregaCorreo").checked =
                registry.como_se_entregan == "POR CORREO";
            document.getElementById("formaEntregaUSB").checked =
                registry.como_se_entregan == "FISICAS POR USB";
            document.getElementById("domicilioCorreo").value =
                registry.domicilio_correo;
            document.getElementById("fechaJuntaAclaraciones").value =
                DateFormatter.dateNormal(
                    registry.fecha_junta_aclaraciones,
                    true
                );
            document.getElementById("horaRegistroJA").value =
                registry.hora_registro_ja;
            document.getElementById("horaJA").value = registry.hora_ja;
            document.getElementById("juntaObligatoriaSi").checked =
                registry.junta_obligatoria == "SÍ" ||
                registry.junta_obligatoria == "Sí";
            document.getElementById("juntaObligatoriaNo").checked =
                registry.junta_obligatoria == "NO" ||
                registry.junta_obligatoria == "No";
            document.getElementById("domicilioJA").value =
                registry.domicilio_ja;
            document.getElementById("tipoJuntaPresencial").checked =
                registry.presencial_digital == "Presencial";
            document.getElementById("tipoJuntaDigital").value =
                registry.presencial_digital == "Digital";
            document.getElementById("domicilio").value = registry.domicilio;
            document.getElementById("fechaPresentacion").value =
                DateFormatter.dateNormal(registry.fecha_presentacion, true);
            document.getElementById("horaRegistroPresentacion").value =
                registry.hora_registro_presentacion;
            document.getElementById("horaApertura").value =
                registry.hora_apertura;
            document.getElementById("partidasEQUIPODECOMPUTO").checked =
                registry.partidas.includes("EQUIPO DE COMPUTO");
            document.getElementById("partidasENERGIA").checked =
                registry.partidas.includes("ENERGIA");
            document.getElementById("partidasPROYECCION").checked =
                registry.partidas.includes("PROYECCION");
            document.getElementById("partidasSOFTWARE").checked =
                registry.partidas.includes("SOFTWARE");
            document.getElementById("partidasPAPELERIA").checked =
                registry.partidas.includes("PAPELERIA");
            document.getElementById("partidasOtros").checked =
                registry.partidas.includes("Otros");
            document.getElementById("requirePreventaSi").checked =
                registry.requiere_preventa == "SÍ" ||
                registry.requiere_preventa == "Sí";
            document.getElementById("requirePreventaNo").checked =
                registry.requiere_preventa == "NO" ||
                registry.requiere_preventa == "No";
            document.getElementById("linkCarpeta").value =
                registry.link_carpeta;

            if (registry.partidas.includes("Otros")) {
                this.setState(
                    {
                        ...this.state,
                        optPartidasOtrosSelected: true,
                    },
                    () => {
                        let partidas = registry.partidas.split(", ");
                        document.getElementById("otraPartida").value =
                            partidas.slice(-1);
                    }
                );
            }

            let urlUpdate = endpoints.bid.update.replace("%ID%", registry.id);

            this.setState({
                title: "Modificar licitación " + registry.nombre,
                urlSave: urlUpdate,
            });
        }
    }

    reviewData() {
        this.validateForm();
        let submit = true;
        const inputs = document.querySelectorAll(`.Form__Input input`);

        for (const input of inputs) {
            if (input.parentNode.classList.contains("Invalid")) {
                this.context.setMessage({
                    type: "error",
                    message: "LLena los campos requeridos",
                });
                submit = false;
                break;
            }
        }

        if (!submit) {
            return;
        }

        this.setState(
            {
                isEditing: false,
            },
            () => {
                this.context.setMessage({
                    type: "info",
                    message:
                        "Revisa que los datos sean correctos, de lo contrario haz las modificaciones correspondientes",
                });
            }
        );
    }

    componentDidMount() {
        const inputs = document.querySelectorAll(`.Form__Input input`);

        for (const input of inputs) {
            input.addEventListener("change", (e) => {
                if (e.target.value != "") {
                    e.target.parentNode.classList.remove("Invalid");
                }
            });
        }

        this.fillForm();
    }

    render() {
        return (
            <div className='FrmBid Dialog'>
                <div className='Dialog__Content'>
                    <div className='Dialog__Title'>
                        {this.state.isEditing
                            ? this.state.title
                            : this.state.titleReview}
                    </div>
                    <div className='Dialog__Body Form__Bid'>
                        {this.state.isEditing ? (
                            <div className='Logo'>
                                <Image src={logoAti} alt='Logo' />
                            </div>
                        ) : null}
                        <div className='Form__Group Col'>
                            <div className='Form__Input'>
                                <input
                                    type='text'
                                    name='nombreLicitacion'
                                    id='nombreLicitacion'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='nombreLicitacion'>
                                    Nombre de la licitación
                                </label>
                            </div>
                        </div>

                        <div className='Form__Group Col-2'>
                            <div className='Form__Input'>
                                <input
                                    type='text'
                                    name='dependenciaLicitante'
                                    id='dependenciaLicitante'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='dependenciaLicitante'>
                                    Dependencia que licita
                                </label>
                            </div>

                            <div className='Form__Input'>
                                <input
                                    type='text'
                                    name='dependenciaUsuario'
                                    id='dependenciaUsuario'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='dependenciaUsuario'>
                                    Dependencia usuario
                                </label>
                            </div>
                        </div>
                        <div className='Form__Group'>
                            <div className='Form__Input'>
                                <input
                                    type='text'
                                    name='empresaParticipantes'
                                    id='empresaParticipantes'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='empresaParticipantes'>
                                    Empresas participantes
                                </label>
                            </div>
                        </div>

                        <div className='Form__Group Col-2'>
                            <div className='Form__Input'>
                                <input
                                    type='date'
                                    name='fechaPublicacion'
                                    id='fechaPublicacion'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='fechaPublicacion'>
                                    Fecha de publicación
                                </label>
                            </div>
                            <div className='Form__Input'>
                                <select
                                    name='dondePublicado'
                                    id='dondePublicado'
                                    required
                                    disabled={!this.state.isEditing}
                                    onChange={(e) =>
                                        this.onChangeOtrosSelected(
                                            e,
                                            "optLugaresOtrosSelected"
                                        )
                                    }>
                                    {this.state.lugaresPublicacion.map(
                                        (lugar) => (
                                            <option value={lugar} key={lugar}>
                                                {lugar}
                                            </option>
                                        )
                                    )}
                                </select>
                                <label htmlFor='dondePublicado'>
                                    Donde se publicó
                                </label>
                            </div>
                        </div>

                        {this.state.optLugaresOtrosSelected && (
                            <div className='Form__Group'>
                                <div className='Form__Input'>
                                    <input
                                        type='text'
                                        name='otrosLugarPublicacion'
                                        id='otrosLugarPublicacion'
                                        required
                                        readOnly={!this.state.isEditing}
                                    />
                                    <label htmlFor='otrosLugarPublicacion'>
                                        Tu respuesta
                                    </label>
                                </div>
                            </div>
                        )}

                        <div className='Form__Group Col-2'>
                            <div className='Form__Input'>
                                <input
                                    type='date'
                                    name='fechaEnvioPreguntas'
                                    id='fechaEnvioPreguntas'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='fechaEnvioPreguntas'>
                                    Fecha de envío de preguntas
                                </label>
                            </div>
                            <div className='Form__Input'>
                                <input
                                    type='time'
                                    name='horaLimiteEnvioPreguntas'
                                    id='horaLimiteEnvioPreguntas'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='horaLimiteEnvioPreguntas'>
                                    Hora límite de envío de preguntas
                                </label>
                            </div>
                        </div>

                        <p>Cómo se entregan</p>
                        <div className='Form__Group Col-2'>
                            <div className='Form__Input Row'>
                                <input
                                    type='radio'
                                    name='comoSeEntregan'
                                    id='formaEntregaCorreo'
                                    value={"POR CORREO"}
                                    disabled={!this.state.isEditing}
                                />
                                <label htmlFor='formaEntregaCorreo'>
                                    Por correo
                                </label>
                            </div>
                            <div className='Form__Input Row'>
                                <input
                                    type='radio'
                                    name='comoSeEntregan'
                                    id='formaEntregaUSB'
                                    value={"FISICAS POR USB"}
                                    disabled={!this.state.isEditing}
                                />
                                <label htmlFor='formaEntregaUSB'>
                                    Fisicas por USB
                                </label>
                            </div>
                        </div>

                        <div className='Form__Group'>
                            <div className='Form__Input'>
                                <input
                                    type='text'
                                    name='domicilioCorreo'
                                    id='domicilioCorreo'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='domicilioCorreo'>
                                    Domicilio y/o correo
                                </label>
                            </div>
                        </div>

                        <div className='Form__Group'>
                            <div className='Form__Input'>
                                <input
                                    type='date'
                                    name='fechaJuntaAclaraciones'
                                    id='fechaJuntaAclaraciones'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='fechaJuntaAclaraciones'>
                                    Fecha de junta de aclaraciones
                                </label>
                            </div>
                        </div>

                        <div className='Form__Group Col-2'>
                            <div className='Form__Input'>
                                <input
                                    type='time'
                                    name='horaRegistroJA'
                                    id='horaRegistroJA'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='horaRegistroJA'>
                                    Hora de registro de junta de aclaraciones
                                </label>
                            </div>
                            <div className='Form__Input'>
                                <input
                                    type='time'
                                    name='horaJA'
                                    id='horaJA'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='horaJA'>
                                    Hora de junta de aclaraciones
                                </label>
                            </div>
                        </div>

                        <p>Junta obligatoria</p>
                        <div className='Form__Group Col-3'>
                            <div className='Form__Input Row'>
                                <input
                                    type='radio'
                                    name='juntaObligatoria'
                                    id='juntaObligatoriaSi'
                                    value={"SÍ"}
                                    disabled={!this.state.isEditing}
                                />
                                <label htmlFor='juntaObligatoriaSi'>SI</label>
                            </div>
                            <div className='Form__Input Row'>
                                <input
                                    type='radio'
                                    name='juntaObligatoria'
                                    id='juntaObligatoriaNo'
                                    value={"NO"}
                                    disabled={!this.state.isEditing}
                                />
                                <label htmlFor='juntaObligatoriaNo'>NO</label>
                            </div>
                        </div>

                        <div className='Form__Group'>
                            <div className='Form__Input'>
                                <input
                                    type='text'
                                    name='domicilioJA'
                                    id='domicilioJA'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='domicilioJA'>
                                    Domicilio JA
                                </label>
                            </div>
                        </div>

                        <p>Es presencial o digital</p>
                        <div className='Form__Group Col-2'>
                            <div className='Form__Input Row'>
                                <input
                                    type='radio'
                                    name='presencialOdigital'
                                    id='tipoJuntaPresencial'
                                    value={"Presencial"}
                                    disabled={!this.state.isEditing}
                                />
                                <label htmlFor='tipoJuntaPresencial'>
                                    Presencial
                                </label>
                            </div>
                            <div className='Form__Input Row'>
                                <input
                                    type='radio'
                                    name='presencialOdigital'
                                    id='tipoJuntaDigital'
                                    value={"Digital"}
                                    disabled={!this.state.isEditing}
                                />
                                <label htmlFor='tipoJuntaDigital'>
                                    Digital
                                </label>
                            </div>
                        </div>

                        <div className='Form__Group'>
                            <div className='Form__Input'>
                                <input
                                    type='text'
                                    name='domicilio'
                                    id='domicilio'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='domicilio'>Domicilio</label>
                            </div>
                        </div>

                        <div className='Form__Group Col-2'>
                            <div className='Form__Input'>
                                <input
                                    type='date'
                                    name='fechaPresentacion'
                                    id='fechaPresentacion'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='fechaPresentacion'>
                                    Fecha de presentación
                                </label>
                            </div>
                            <div className='Form__Input'>
                                <input
                                    type='time'
                                    name='horaRegistroPresentacion'
                                    id='horaRegistroPresentacion'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='horaRegistroPresentacion'>
                                    Hora de registro de presentación
                                </label>
                            </div>
                        </div>

                        <div className='Form__Group'>
                            <div className='Form__Input'>
                                <input
                                    type='time'
                                    name='horaApertura'
                                    id='horaApertura'
                                    required
                                    readOnly={!this.state.isEditing}
                                />
                                <label htmlFor='horaApertura'>
                                    Hora de apertura
                                </label>
                            </div>
                        </div>

                        <p>Sobre las partidas</p>
                        <div className='Form__Group Col-2'>
                            {this.state.partidas.map((partida) => (
                                <div
                                    className='Form__Input Row'
                                    key={
                                        "partidas_" +
                                        partida.replaceAll(" ", "")
                                    }>
                                    <input
                                        type='checkbox'
                                        name='partidas'
                                        id={
                                            "partidas" +
                                            partida.replaceAll(" ", "")
                                        }
                                        value={partida}
                                        onChange={(e) => {
                                            this.onChangeOtrosSelected(
                                                e,
                                                "optPartidasOtrosSelected"
                                            );
                                        }}
                                        disabled={!this.state.isEditing}
                                    />
                                    <label
                                        htmlFor={
                                            "partidas" +
                                            partida.replaceAll(" ", "")
                                        }>
                                        {partida}
                                    </label>
                                </div>
                            ))}
                        </div>

                        {this.state.optPartidasOtrosSelected && (
                            <div className='Form__Group'>
                                <div className='Form__Input'>
                                    <input
                                        type='text'
                                        name='otraPartida'
                                        id='otraPartida'
                                        readOnly={!this.state.isEditing}
                                    />
                                    <label htmlFor='otraPartida'>
                                        Tu respuesta
                                    </label>
                                </div>
                            </div>
                        )}

                        <p>Requiere preventa</p>
                        <div className='Form__Group Col-2'>
                            <div className='Form__Input Row'>
                                <input
                                    type='radio'
                                    name='requierePreventa'
                                    id='requirePreventaSi'
                                    value={"SÍ"}
                                    disabled={!this.state.isEditing}
                                />
                                <label htmlFor='requirePreventaSi'>SI</label>
                            </div>
                            <div className='Form__Input Row'>
                                <input
                                    type='radio'
                                    name='requierePreventa'
                                    id='requirePreventaNo'
                                    value={"NO"}
                                    disabled={!this.state.isEditing}
                                />
                                <label htmlFor='requirePreventaNo'>NO</label>
                            </div>
                        </div>

                        <div className='Form__Group'>
                            <div className='Form__Input'>
                                <input
                                    type='url'
                                    name='linkCarpeta'
                                    id='linkCarpeta'
                                    required
                                    readOnly={!this.state.isEditing}
                                    placeholder='https://example.example'
                                />
                                <label htmlFor='linkCarpeta'>
                                    Link carpeta
                                </label>
                            </div>
                        </div>
                    </div>
                    <div className='Dialog__Footer'>
                        <div
                            className='Button Button__secondary'
                            onClick={
                                this.state.isEditing
                                    ? () => this.props.closeModal()
                                    : () => this.setState({ isEditing: true })
                            }>
                            {this.state.isEditing ? "Cerrar" : "Atrás"}
                        </div>
                        {this.state.isEditing ? (
                            <div
                                className={`Button ${
                                    this.state.valid
                                        ? "Button__primary"
                                        : "Button__Disabled"
                                }`}
                                onClick={
                                    this.state.valid
                                        ? () => this.reviewData()
                                        : null
                                }>
                                Continuar
                            </div>
                        ) : (
                            <div
                                className={`Button ${
                                    this.state.valid
                                        ? "Button__primary"
                                        : "Button__Disabled"
                                }`}
                                onClick={
                                    this.state.valid
                                        ? () =>
                                              this.setState({
                                                  showDialogConfirm: true,
                                              })
                                        : null
                                }>
                                Enviar datos
                            </div>
                        )}
                    </div>
                </div>

                {this.state.showDialogConfirm ? (
                    <DialogConfirm
                        proceed={() => this.storeBid()}
                        closeModal={() =>
                            this.setState({ showDialogConfirm: false })
                        }
                    />
                ) : null}
            </div>
        );
    }
}
