import React, { Component } from "react";
import axios from "axios";

import AppContext from "@context/AppContext";
import ConvertArray from "@utils/ConvertArray";
import TelegramHelper from "@utils/TelegramHelper";
import DateFormatter from "@utils/DateFormatter";
import endpoints from "@services/Api/endpoints";
import Commons from "@utils/Commons";

export default class FrmUpdateStatus extends Component {
    constructor() {
        super();

        this.state = {
            statuses: [],
            label: "",
            additionalStatus: "",
            reasonNoPres: Commons.reasonsNoPresentation,
            showNoReasons: false,
            currentStatus: "",
            selectedReason: "",
            disableButton: false,
            availableUsers: [],
        };
    }

    static contextType = AppContext;

    defineStatuses(status) {
        let currentStatuses = [];
        let label = "Estatus";
        let currentStatus = "";
        let selectedReason = "";
        let showNoReasons = false;
        switch (status) {
            case "preguntas":
                currentStatuses = Commons.statuses.questions;
                label = "Estatus preguntas";
                currentStatus = this.props.registry.estatus_preguntas;
                break;
            case "junta":
                currentStatuses = Commons.statuses.meeting;
                label = "Estatus junta";
                currentStatus = this.props.registry.estatus_junta;
                break;
            case "ficha":
                currentStatuses = Commons.statuses.ticket;
                label = "Estatus ficha";
                currentStatus = this.props.registry.estatus_ficha;
                break;
            case "presentacion":
                currentStatuses = Commons.statuses.presentation;
                label = "Estatus presentación";
                currentStatus = this.props.registry.estatus_presentacion;
                showNoReasons = currentStatus?.includes("No");
                selectedReason = this.props.registry.razon_no_presentacion;
                break;
            case "final":
                currentStatuses = [
                    ...[Commons.statuses.final_initial],
                    ...Commons.statuses.final,
                ];
                label = "Estatus final";
                currentStatus = this.props.registry.estatus_final;
                break;
            case "statusp":
                currentStatuses = [
                    ...[Commons.statuses.final2_initial],
                    ...Commons.statuses.final2,
                ];
                label = "Estatus final";
                currentStatus = this.props.registry.estatus;
                break;
            default:
                break;
        }

        this.setState({
            statuses: currentStatuses,
            label: label,
            currentStatus: currentStatus,
            selectedReason: selectedReason,
            showNoReasons: showNoReasons,
        });
    }

    getFormData() {
        let formData = [];
        formData["id"] = this.props.registry.id;
        formData["estatus"] = document.getElementById("status").value;

        const userName = this.context.state.user.name;

        switch (this.props.type) {
            case "preguntas":
                formData["usuarioPreguntas"] = userName;
                break;
            case "junta":
                formData["usuarioJunta"] = userName;
                break;
            case "ficha":
                formData["usuarioFicha"] = userName;
                break;
            case "presentacion":
                formData["usuarioPresentacion"] = userName;
                break;
            case "final":
                formData["usuarioFinal"] = userName;
                break;
            default:
                break;
        }

        return formData;
    }

    async setReasonNoPresentation(reset = false) {
        const reason = reset ? "" : document.getElementById("razon").value;

        try {
            await axios
                .post(endpoints.bid.no_presentacion, {
                    id: this.props.registry.id,
                    razonNoP: reason,
                })
                .then((response) => {
                    const now = new Date();
                    const message = `
${DateFormatter.fullDate(now)}
${this.props.registry.nombre}
Se actualizó la razón de no presentación de la licitación: ${reason}
                `;

                    if (!reset) {
                        TelegramHelper.sendMessage(message);
                    }
                });
        } catch (error) {
            console.error(error);
        }
    }

    msgPreguntas(status) {
        let message = `Las preguntas de la licitación ${this.props.registry.nombre}`;

        if (status.includes("no listas")) {
            return message + " no está listas.";
        } else if (status.includes("no requeridas")) {
            return message + " no se requiere.";
        } else if (status.includes("listas")) {
            return message + " están listas.";
        } else {
            return `Estatus de las preguntas: ${status}.`;
        }
    }

    msgJunta(status) {
        let message = `La junta de la licitación ${this.props.registry.nombre}`;

        if (status == "No lista") {
            return message + " no está lista.";
        } else if (status == "Listo") {
            return message + " está lista.";
        } else {
            return `Estatus de la junta: ${status}.`;
        }
    }

    msgFichas(status) {
        let message = `Las fichas de la licitación ${this.props.registry.nombre}`;

        if (status.includes("no listas")) {
            return message + " no está listas.";
        } else if (status.includes("no requeridas")) {
            return message + " no se requieren.";
        } else if (status.includes("listas")) {
            return message + " están listas.";
        } else {
            return `Estatus de las fichas: ${status}.`;
        }
    }

    async msgPresentacion(status) {
        if (status == "Presentada") {
            this.props.updateFinalEstatus("En espera de fallo");
            await this.setReasonNoPresentation(true);
            return `!La licitación ${this.props.registry.nombre} ha sido presentada exitosamente!`;
        } else {
            this.props.updateFinalEstatus("No se participó");
            await this.setReasonNoPresentation();
            return `La licitación ${this.props.registry.nombre} no fue presentada.`;
        }
    }

    msgFinal(status) {
        const now = new Date();
        const date = DateFormatter.dateNormal(now, true);
        switch (status) {
            case "Se ganó":
                return `
${date}
¡Felicidades! Se ganó la licitación ${this.props.registry.nombre}`;
            case "Se perdió":
                return `
${date}
Se perdió la licitación ${this.props.registry.nombre}`;
            case "Desertó":
                return `
${date}
La licitación ${this.props.registry.nombre} fue desierta`;
            case "Se está trabajando":
            case "En espera de fallo":
                return null;
        }
    }

    msgStatusp(status) {
        if (status !== "Finalizado") {
            return null;
        }

        const message =
            this.props.entity === "education"
                ? Commons.msgTemplates.education.finished
                      .replace(
                          "%INSTITUTION%",
                          this.props.registry.nombre_institucion
                      )
                      .replace("%CUSTOMER%", this.props.registry.nombre_cliente)
                      .replace("%SELLER%", this.props.registry.usuario)
                      .replace("%USER%", this.context.state.user.name)
                : Commons.msgTemplates.presale.finished
                      .replace(
                          "%ENTERPRISE%",
                          this.props.registry.nombre_empresa
                      )
                      .replace("%CUSTOMER%", this.props.registry.nombre_cliente)
                      .replace("%SELLER%", this.props.registry.usuario)
                      .replace("%USER%", this.context.state.user.name);

        return message;
    }

    async sendEmail(status) {
        if (this.props.type == "final") {
            const now = new Date();
            const date = DateFormatter.dateNormal(now, true);

            const response = await axios.get(endpoints.email_notification.get);
            const correos = response.data;
            let url = null;
            let data = null;

            switch (status) {
                case "Se ganó":
                    url = endpoints.email_notification.bid_won;
                    data = {
                        correosDestino: correos,
                        asunto: `¡Felicidades! Se ganó la licitación ${this.props.registry.nombre}`,
                        mensaje: `
    ${date}
    ¡Felicidades! Se ganó la licitación ${this.props.registry.nombre}`,
                    };

                    break;
                case "Se perdió":
                    url = endpoints.email_notification.bid_lost;
                    data = {
                        correosDestino: correos,
                        asunto: `Se perdió la licitación ${this.props.registry.nombre}`,
                        mensaje: `
    ${date}
    Se perdió la licitación ${this.props.registry.nombre}`,
                    };
                    break;
                case "Desertó":
                    url = endpoints.email_notification.bid_defect;
                    data = {
                        correosDestino: correos,
                        asunto: `La licitación ${this.props.registry.nombre} fue desierta`,
                        mensaje: `
    ${date}
    La licitación ${this.props.registry.nombre} fue desierta`,
                    };
                    break;
                default:
                    break;
            }

            try {
                if (url && data) {
                    axios.post(url, data).catch((response) => {
                        console.error(response);
                    });
                }
            } catch (error) {
                console.error(error);
            }
        }
    }

    async getTGMessage() {
        const status = document.getElementById("status").value;
        let message = "";
        switch (this.props.type) {
            case "preguntas":
                message = this.msgPreguntas(status);
                break;
            case "junta":
                message = this.msgJunta(status);
                break;
            case "ficha":
                message = this.msgFichas(status);
                break;
            case "presentacion":
                message = await this.msgPresentacion(status);
                break;
            case "final":
                message = this.msgFinal(status);
            case "statusp":
                message = this.msgStatusp(status);
                break;
            default:
                break;
        }

        return message;
    }

    async sentTelegramMsg() {
        try {
            const message = await this.getTGMessage();
            if (message) {
                TelegramHelper.sendMessage(message);
            }
        } catch (error) {
            console.error("Send Telegram Message", error);
        }
    }

    setStatus() {
        try {
            const formData = this.getFormData();
            const data = ConvertArray.toObject(formData);

            axios
                .post(this.props.url, data)
                .then(async (response) => {
                    this.context.setMessage({
                        type: "success",
                        message:
                            response.data.message ??
                            "Estatus actualizado correctamente",
                    });

                    this.sendEmail();
                    await this.sentTelegramMsg();

                    axios.get(this.props.urlData).then((response) => {
                        this.props.updateData(response);
                    });

                    this.props.closeModal();
                })
                .catch((response) => {
                    console.error(response);

                    this.context.setMessage({
                        type: "error",
                        message: "Ocurrió un error, intente más tarde",
                    });
                });
        } catch (error) {
            console.error(response);

            this.context.setMessage({
                type: "error",
                message: "Ocurrió un error, intente más tarde",
            });
        }
    }

    onChangeSelection(e) {
        if (
            e.target.value.includes("No") &&
            this.props.type == "presentacion"
        ) {
            this.setState({
                showNoReasons: true,
                currentStatus: e.target.value,
            });
        } else {
            this.setState({
                showNoReasons: false,
                currentStatus: e.target.value,
            });
        }

        if (e.target.value == "Finalizado") {
            if (
                this.state.availableUsers.includes(this.context.state.user.name)
            ) {
                this.setState({ disableButton: false });
            } else {
                this.setState({ disableButton: true });
            }
        } else {
            if (this.state.disableButton) {
                this.setState({ disableButton: false });
            }
        }
    }

    componentDidMount() {
        this.defineStatuses(this.props.type);
        this.setState({
            availableUsers: [
                this.props.registry.vendedor,
                this.props.registry.seguidor,
            ],
        });
    }

    componentDidUpdate() {
        if (
            this.state.currentStatus != document.getElementById("status").value
        ) {
            if (
                this.state.currentStatus != "" &&
                this.state.statuses.includes(this.state.currentStatus)
            ) {
                document.getElementById("status").value =
                    this.state.currentStatus;
            }
        }
    }

    render() {
        return (
            <div className='FrmUpdateStatus Dialog'>
                <div className='Dialog__Content'>
                    <div className='Dialog__Title'>
                        {this.props.registry.nombre}
                    </div>
                    <div className='Dialog__Body'>
                        <div className='Form__Group'>
                            <div className='Form__Input'>
                                <select
                                    name='status'
                                    id='status'
                                    // defaultValue={this.state.currentStatus}
                                    onChange={(e) => this.onChangeSelection(e)}>
                                    {this.state.statuses.map((status) => (
                                        <option value={status} key={status}>
                                            {status}
                                        </option>
                                    ))}
                                </select>
                                <label htmlFor='status'>
                                    {this.state.label}
                                </label>
                            </div>
                        </div>

                        {this.state.disableButton ? (
                            <div>
                                <p>
                                    La oportunidad solo puede ser finalizada por
                                    el <b>Preventa asignado</b> o el{" "}
                                    <b>Acompañante</b>
                                </p>
                            </div>
                        ) : null}

                        {this.state.showNoReasons && (
                            <div className='Form__Group'>
                                <div className='Form__Input'>
                                    <select name='razon' id='razon'>
                                        {this.state.reasonNoPres.map(
                                            (reason) => (
                                                <option
                                                    value={reason}
                                                    key={reason}
                                                    selected={
                                                        this.state
                                                            .selectedReason ==
                                                        reason
                                                    }>
                                                    {reason}
                                                </option>
                                            )
                                        )}
                                    </select>
                                </div>
                            </div>
                        )}
                    </div>
                    <div className='Dialog__Footer'>
                        <div
                            className='Button Button__secondary'
                            onClick={() => this.props.closeModal()}>
                            Cerrar
                        </div>
                        <div
                            className={`Button Button__primary ${
                                this.state.disableButton
                                    ? "Button__Disabled"
                                    : ""
                            }`}
                            onClick={
                                this.state.disableButton
                                    ? null
                                    : () => this.setStatus()
                            }>
                            guardar
                        </div>
                    </div>
                </div>
            </div>
        );
    }
}
