import React, { Component } from "react";
import Chart from "chart.js/auto";

import Commons from "@utils/Commons";
import RowColor from "@utils/RowColor";

export default class MonthlyChart extends Component {
    constructor() {
        super();

        this.state = {
            canvasId: "monthlyChart",
            labels: [],
            data: [],
            tempData: [],
        };
    }

    getDatasets() {
        let dataset = [];

        for (const label of this.state.labels) {
            const data = this.state.data.filter((registry) => {
                if (registry.estatus_final != undefined) {
                    return registry.estatus_final == label;
                } else if (registry.estatus) {
                    return registry.estatus == label;
                } else {
                    return false;
                }
            });
            dataset.push(data ? data.length : 0);
        }

        let backgroundColors = [];

        for (const status of this.state.labels) {
            backgroundColors.push(
                this.props.switchStatus
                    ? RowColor.statusColor(status)
                    : RowColor.color(status)
            );
        }

        return {
            labels: this.state.labels,
            datasets: [
                {
                    type: "bar",
                    label: this.props.label,
                    data: dataset,
                    backgroundColor: backgroundColors,
                    borderColor: "blue",
                    borderWidth: 3,
                    datalabels: {
                        enabled: true,
                        anchor: "end",
                        align: "end",
                        position: "top",
                        offset: 0,
                        padding: 1,
                        color: "#a7a7a7",
                        labels: {
                            value: {
                                font: {
                                    size: 13,
                                },
                            },
                            title: {
                                color: "black",
                                font: {
                                    size: 13,
                                },
                            },
                        },
                        formatter: function (value, context) {
                            return value;
                        },
                    },
                },
            ],
        };
    }

    getChartConfig() {
        const dataset = this.getDatasets();

        if (dataset) {
            return {
                data: dataset,
                options: {
                    responsive: true,
                    maintainAspectRatio: false,
                    legend: {
                        display: true,
                    },
                    scales: {
                        x: {
                            border: {
                                display: false,
                            },
                            grid: {
                                display: false,
                            },
                            ticks: {
                                display: true,
                            },
                        },
                        y: {
                            border: {
                                display: false,
                            },
                            grid: {
                                display: false,
                            },
                            ticks: {
                                display: false,
                            },
                        },
                    },
                },
            };
        }
    }

    filterData(e) {
        let data = [];

        if (e.target.value != "") {
            data = this.state.tempData.filter((registry) =>
                registry.created_at.includes(e.target.value)
            );
        } else {
            data = this.state.tempData;
        }

        this.setState(
            {
                data: data,
            },
            () => this.drawChart()
        );
    }

    drawChart() {
        const chartConfig = this.getChartConfig();

        if (chartConfig) {
            let canvasMonthly = document.getElementById(this.state.canvasId);
            let chartMonthly = Chart.getChart(this.state.canvasId);

            if (chartMonthly != undefined) {
                chartMonthly.destroy();
            }

            chartMonthly = new Chart(canvasMonthly, chartConfig);
        }
    }

    componentDidMount() {
        let labels = [];

        if (this.props.switchStatus) {
            labels = Commons.statuses.final2;
            labels.unshift(Commons.statuses.final2_initial);
        } else {
            labels = Commons.statuses.final;
            labels.unshift(Commons.statuses.final_initial);
        }
        this.setState(
            {
                labels: [...new Set([...labels])],
                data: this.props.data,
                tempData: this.props.data,
            },
            () => this.drawChart()
        );
    }

    render() {
        return (
            <div className='Chart__Container'>
                <div className='Chart__Content'>
                    <div className='Chart__Filter'>
                        <div className='Form__Group'>
                            <div className='Form__Input'>
                                <input
                                    type='month'
                                    name='month'
                                    id='month'
                                    onChange={(e) => this.filterData(e)}
                                />
                                <label htmlFor='month'>Mes</label>
                            </div>
                        </div>
                    </div>
                    <div className='Canvas__Container'>
                        <canvas
                            id={this.state.canvasId}
                            width={500}
                            height={500}></canvas>
                    </div>
                </div>
            </div>
        );
    }
}
