"use client"

import React from "react";
import { useGoogleLogin } from "@react-oauth/google";
import { useRouter } from "next/navigation";
import Cookies from "js-cookie";

import axios from "axios";
import CryptoJS from "crypto-js";
import Image from "next/image";
import Head from "next/head";

import endpoints from "@services/Api/endpoints";

import { useAppContext } from "@context/AppContext";

import googleIcon from "@img/google-icon.png";
import ValidateUser from "@components/ValidateUser";

const Login = () => {
    const { setUser } = useAppContext();
    const router = useRouter();

    const getUserInfo = (response) => {
        axios
            .get(
                endpoints.google.userinfo +
                `?access_token=${response.access_token}`,
                {
                    headers: {
                        Authorization: `Bearer ${response.access_token}`,
                        Accept: "application/json",
                    },
                }
            )
            .then(async (response) => {
                let encryptedUser = CryptoJS.AES.encrypt(
                    JSON.stringify(response.data),
                    process.env.REACT_APP_KEY
                ).toString();
                Cookies.set("loggedUser", encryptedUser, { expires: 5 });

                setUser(response.data);
                router.push("/dashboard");

            })
            .catch((error) => console.error(error));
    };

    const login = useGoogleLogin({
        onSuccess: (response) => getUserInfo(response),
        onError: (error) => console.log("Login failed:", error),
    });

    return (
        <>
            <Head>
                <title>Login</title>
            </Head>
            <div className='Login'>
                <div className='Login__container'>
                    <img src={process.env.REACT_APP_LOGO_URL} alt='Logo' />
                    <h1>Bienvenidos</h1>
                    <h4>{process.env.REACT_APP_NAME}</h4>
                    <button type='button' onClick={() => login()}>
                        <Image src={googleIcon} alt='Google icon' width={35} height={35} />
                        <span>Iniciar Sesión</span>
                    </button>
                </div>
                <ValidateUser router={router} />
            </div>
        </>
    );
};

export default Login;
