const regexpUrl =
    /https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{1,256}\.[a-zA-Z0-9()]{1,6}\b([-a-zA-Z0-9()@:%_\+.~#?&//=]*)/;
const regexpEmail = /^[\w-\.]+@([\w-]+\.)+[\w-]{2,4}$/;

const Commons = () => { };

Commons.statuses = {
    ticket: ["Fichas listas", "Fichas no listas", "Fichas no requeridas"],
    questions: [
        "Preguntas listas",
        "Preguntas no listas",
        "Preguntas no requeridas",
    ],
    meeting: ["Listo", "No lista"],
    presentation: ["Presentada", "No presentada"],
    final: [
        "En espera de fallo",
        "Se ganó",
        "Se perdió",
        "Desertó",
        "No se participó",
    ],
    final_initial: "Se está trabajando",
    final2: ["En terceros", "Propuesta lista", "Finalizado"],
    final2_initial: "En proceso",
};

Commons.reasonsNoPresentation = [
    "Sin apoyo de fabricante/Mayorista",
    "Sin documentación técnica",
    "Sin documentación administrativa",
    "No se llegó a tiempo",
    "No se asistió a JA Obligatoria",
    "Por indicaciones",
];

Commons.validateInputs = (inputsToValidate) => {
    for (const input of inputsToValidate) {
        if (input.required) {
            if (input.value == "") {
                input.parentNode.classList.add("Invalid");
            } else {
                let validValue = true;
                switch (input.type) {
                    case "url":
                        validValue = regexpUrl.test(input.value);
                        break;
                    case "email":
                        validValue = regexpEmail.test(input.value);
                        break;
                    default:
                        break;
                }

                if (validValue) {
                    input.parentNode.classList.remove("Invalid");
                } else {
                    if (!input.parentNode.classList.contains("Invalid"))
                        input.parentNode.classList.add("Invalid");
                }
            }
        }
    }
};

Commons.validateInputRadio = (inputsRadio) => {
    let radioInputValid = false;
    let radioParent = [];
    for (const radio of inputsRadio) {
        radioParent.push(radio.parentNode);
        if (radio.checked) {
            radioInputValid = true;
        }
    }

    if (!radioInputValid) {
        for (const parent of radioParent) {
            parent.classList.add("Invalid");
        }
    } else {
        for (const parent of radioParent) {
            parent.classList.remove("Invalid");
        }
    }
};

Commons.msgTemplates = {
    bid: {
        msgSeller:
            "La licitacion <b>%BID%</b> registrado por <b>%SELLER%</b> está siendo atendido por <b>%USER%</b>",
        msgFollower:
            "La licitacion <b>%BID%</b> registrado por <b>%SELLER%</b> está siendo acompañado por <b>%USER%</b>",
        products: {
            statuses: [
                { value: 1, label: "Productos listos" },
                { value: 2, label: "No se maneja" },
            ],
            messages: [
                {
                    key: 1,
                    msg: "Los productos solicitados en la licitación <b>%BID%</b> están listos. Estatus cambiado por <b>%USER%</b>",
                },
                {
                    key: 2,
                    msg: "Los productos solicitados en la licitación <b>%BID%</b> no se manejan. Estatus cambiado por <b>%USER%</b>",
                },
            ],
        },
    },
    presale: {
        msgSeller:
            "El requerimiento de <b>%ENTERPRISE%</b> y <b>%CUSTOMER%</b> registrado por <b>%SELLER%</b> está siendo atendido por <b>%USER%</b>",
        msgFollower:
            "El requerimiento de <b>%ENTERPRISE%</b> y <b>%CUSTOMER%</b> registrado por <b>%SELLER%</b> está siendo acompañado por <b>%USER%</b>",
        finished:
            "El requerimiento de <b>%ENTERPRISE%</b> y <b>%CUSTOMER%</b> registrado por <b>%SELLER%</b> fue finalizado por <b>%USER%</b>",
    },
    education: {
        msgSeller:
            "El requerimiento de <b>%INSTITUTION%</b> y <b>%CUSTOMER%</b> registrado por <b>%SELLER%</b> está siendo atendido por <b>%USER%</b>",
        msgFollower:
            "El requerimiento de <b>%INSTITUTION%</b> y <b>%CUSTOMER%</b> registrado por <b>%SELLER%</b> está siendo acompañado por <b>%USER%</b>",
        finished:
            "El requerimiento de <b>%INSTITUTION%</b> y <b>%CUSTOMER%</b> registrado por <b>%SELLER%</b> fue finalizado por <b>%USER%</b>",
    },
};

export default Commons;
